==> zio-aws-macie2_2.12-5.17.130.2-sources.jar: zio/aws/macie2/model/DescribeClassificationJobRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DescribeClassificationJobRequest(jobId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.DescribeClassificationJobRequest = {
    import DescribeClassificationJobRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.DescribeClassificationJobRequest
      .builder()
      .jobId(__string.unwrap(jobId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.macie2.model.DescribeClassificationJobRequest.ReadOnly =
    zio.aws.macie2.model.DescribeClassificationJobRequest.wrap(buildAwsValue())
}
object DescribeClassificationJobRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.DescribeClassificationJobRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.DescribeClassificationJobRequest =
      zio.aws.macie2.model.DescribeClassificationJobRequest(jobId)
    def jobId: __string
    def getJobId: ZIO[Any, Nothing, __string] = ZIO.succeed(jobId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.DescribeClassificationJobRequest
  ) extends zio.aws.macie2.model.DescribeClassificationJobRequest.ReadOnly {
    override val jobId: __string =
      zio.aws.macie2.model.primitives.__string(impl.jobId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.DescribeClassificationJobRequest
  ): zio.aws.macie2.model.DescribeClassificationJobRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-macie2_2.13-6.20.42.2-sources.jar: zio/aws/macie2/model/DescribeClassificationJobRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DescribeClassificationJobRequest(jobId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.DescribeClassificationJobRequest = {
    import DescribeClassificationJobRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.DescribeClassificationJobRequest
      .builder()
      .jobId(jobId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.macie2.model.DescribeClassificationJobRequest.ReadOnly =
    zio.aws.macie2.model.DescribeClassificationJobRequest.wrap(buildAwsValue())
}
object DescribeClassificationJobRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.DescribeClassificationJobRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.DescribeClassificationJobRequest =
      zio.aws.macie2.model.DescribeClassificationJobRequest(jobId)
    def jobId: __string
    def getJobId: ZIO[Any, Nothing, __string] = ZIO.succeed(jobId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.DescribeClassificationJobRequest
  ) extends zio.aws.macie2.model.DescribeClassificationJobRequest.ReadOnly {
    override val jobId: __string = impl.jobId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.DescribeClassificationJobRequest
  ): zio.aws.macie2.model.DescribeClassificationJobRequest.ReadOnly =
    new Wrapper(impl)
}
